@@ -1,4 +1,4 @@
-# $Id: fastCor.R, v 1.1.5 2014/11/12 12:07:00 EPS JHU $                #
+# $Id: fastCor.R, v1.1.6 2015/03/01 12:00:00 hsbadr EPS JHU            #
 #----------------------------------------------------------------------#
 # This function is a part of HiClimR R package.                        #
 #----------------------------------------------------------------------#
@@ -29,18 +29,19 @@
 #  1.1.4    |  09/01/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
 #  1.1.5    |  11/12/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
 #----------------------------------------------------------------------#
-# COPYRIGHT(C) Department of Earth and Planetary Sciences, JHU.        #
+#  1.1.6    |  01/03/15  |  GitHub    |  Hamada Badr  |  badr@jhu.edu  #
+#----------------------------------------------------------------------#
+# COPYRIGHT(C) 2013-2015 Earth and Planetary Sciences (EPS), JHU.      #
 #----------------------------------------------------------------------#
 # Function: Fast correlation for large matrices                        #
 #----------------------------------------------------------------------#
 
-fastCor <- function (xt)
-{
+fastCor <- function(xt) {
+
     x <- t(xt) - colMeans(xt)
     
-    if (.Machine$sizeof.pointer == 8)
-    {
-        r <- tcrossprod(x / sqrt(rowSums(x^2)))
+    if (.Machine$sizeof.pointer == 8) {
+        r <- tcrossprod(x/sqrt(rowSums(x^2)))
     } else {
         r <- cor(xt)
     }
