@@ -1,4 +1,4 @@
-# $Id: grid2D.R, v 1.1.5 2014/11/12 12:07:00 EPS JHU $                 #
+# $Id: grid2D.R, v1.1.6 2015/03/01 12:00:00 hsbadr EPS JHU             #
 #----------------------------------------------------------------------#
 # This function is a part of HiClimR R package.                        #
 #----------------------------------------------------------------------#
@@ -29,22 +29,23 @@
 #  1.1.4    |  09/01/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
 #  1.1.5    |  11/12/14  |  Updated   |  Hamada Badr  |  badr@jhu.edu  #
 #----------------------------------------------------------------------#
-# COPYRIGHT(C) Department of Earth and Planetary Sciences, JHU.        #
+#  1.1.6    |  01/03/15  |  GitHub    |  Hamada Badr  |  badr@jhu.edu  #
+#----------------------------------------------------------------------#
+# COPYRIGHT(C) 2013-2015 Earth and Planetary Sciences (EPS), JHU.      #
 #----------------------------------------------------------------------#
 # Function: Generate longitude and latitude grid matrices              #
 #----------------------------------------------------------------------#
 
-grid2D <- function (lon=lon, lat=lat)
-{
-    gGrid <- list()
+grid2D <- function(lon = lon, lat = lat) {
 
+    gGrid <- list()
+    
     lon <- unique(lon)
     lat <- unique(lat)
-    if (!is.null(lon) && !is.null(lat))
-    {
+    if (!is.null(lon) && !is.null(lat)) {
         gGrid$lon <- tcrossprod(rep(1, length(lat)), lon)
         gGrid$lat <- tcrossprod(lat, rep(1, length(lon)))
     }
-
+    
     return(gGrid)
 }
